==> libdatetime-locale-perl_1.16.orig.tar.gz: DateTime-Locale-1.16/share/zu.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'week' w 'of' y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "zu",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mso",
    "Bil",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Son"
  ],
  day_format_narrow => [
    "M",
    "B",
    "T",
    "S",
    "H",
    "M",
    "S"
  ],
  day_format_wide => [
    "UMsombuluko",
    "ULwesibili",
    "ULwesithathu",
    "ULwesine",
    "ULwesihlanu",
    "UMgqibelo",
    "ISonto"
  ],
  day_stand_alone_abbreviated => [
    "Mso",
    "Bil",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Son"
  ],
  day_stand_alone_narrow => [
    "M",
    "B",
    "T",
    "S",
    "H",
    "M",
    "S"
  ],
  day_stand_alone_wide => [
    "UMsombuluko",
    "ULwesibili",
    "ULwesithathu",
    "ULwesine",
    "ULwesihlanu",
    "UMgqibelo",
    "ISonto"
  ],
  era_abbreviated => [
    "BC",
    "AD"
  ],
  era_narrow => [
    "BC",
    "AD"
  ],
  era_wide => [
    "BC",
    "AD"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Zulu",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mas",
    "Eph",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sep",
    "Okt",
    "Nov",
    "Dis"
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "UMasingana",
    "Februwari",
    "Mashi",
    "Ephreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septhemba",
    "Okthoba",
    "Novemba",
    "Disemba"
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mas",
    "Eph",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sep",
    "Okt",
    "Nov",
    "Dis"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Januwari",
    "Februwari",
    "Mashi",
    "Ephreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septhemba",
    "Okthoba",
    "Novemba",
    "Disemba"
  ],
  name => "Zulu",
  native_language => "isiZulu",
  native_name => "isiZulu",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "ikota yesi-1",
    "ikota yesi-2",
    "ikota yesi-3",
    "ikota yesi-4"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "ikota yesi-1",
    "ikota yesi-2",
    "ikota yesi-3",
    "ikota yesi-4"
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/zu.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "zu",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mso",
    "Bil",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Son",
  ],
  day_format_narrow => [
    "M",
    "B",
    "T",
    "S",
    "H",
    "M",
    "S",
  ],
  day_format_wide => [
    "UMsombuluko",
    "ULwesibili",
    "ULwesithathu",
    "ULwesine",
    "ULwesihlanu",
    "UMgqibelo",
    "ISonto",
  ],
  day_stand_alone_abbreviated => [
    "Mso",
    "Bil",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Son",
  ],
  day_stand_alone_narrow => [
    "M",
    "B",
    "T",
    "S",
    "H",
    "M",
    "S",
  ],
  day_stand_alone_wide => [
    "UMsombuluko",
    "ULwesibili",
    "ULwesithathu",
    "ULwesine",
    "ULwesihlanu",
    "UMgqibelo",
    "ISonto",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "BC",
    "AD",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Zulu",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mas",
    "Eph",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "E",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januwari",
    "Februwari",
    "Mashi",
    "Ephreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septhemba",
    "Okthoba",
    "Novemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mas",
    "Eph",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januwari",
    "Februwari",
    "Mashi",
    "Ephreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septhemba",
    "Okthoba",
    "Novemba",
    "Disemba",
  ],
  name => "Zulu",
  native_language => "isiZulu",
  native_name => "isiZulu",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "ikota yesi-1",
    "ikota yesi-2",
    "ikota yesi-3",
    "ikota yesi-4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "ikota yesi-1",
    "ikota yesi-2",
    "ikota yesi-3",
    "ikota yesi-4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}
